@@ -50,11 +50,7 @@ class Or(Matcher):
         self.matchers = matchers
 
     def _matches(self, other: Any) -> bool:
-        passed = any(self.nested_match(matcher, other) for matcher in self.matchers)
-        if passed == self.expected_result:
-            for matcher in self.matchers:
-                self.nested_reset(matcher)
-        return passed
+        return any(self.nested_match(matcher, other) for matcher in self.matchers)
 
     def _description(self) -> str:
         return ', '.join(map(repr, self.matchers))
